@@ -62,34 +62,41 @@ class WeLog():
             return True
 
     def info(self,content):
-        if(self.init_config["path"]==""):
-            print("请先配置log文件信息")
-            return 
-        if("log" != self.init_config["filename_suffix"]):
-            print("日志文件必须以log结尾，请重新配置正确")
-            return 
-        if(self.whether_first_running()):
-            #首次运行
-            ###print("首次运行")
-            cur_date=str(datetime.datetime.now()).split(" ")[0]
-            ###cur_date=str(datetime.datetime.now()).replace(" ","").replace(":","")
-            self.date_info={"ori":cur_date}
-            filename=self.init_config["filename_pre"]+"_"+cur_date+".log"
-            fullpath = os.path.join(self.init_config["path"], filename)
-            self.log = self.init_log(fullpath,filename)
-        else:
-            #非首次运行
-            ###print("非首次运行")
-            if(self.whether_init_log(self.date_info["ori"])):
-                #跨天，重新初始化
+        try:
+            try:
+                print(content)
+            except Exception as err:
+                print(err)
+            if(self.init_config["path"]==""):
+                print("请先配置log文件信息")
+                return 
+            if("log" != self.init_config["filename_suffix"]):
+                print("日志文件必须以log结尾，请重新配置正确")
+                return 
+            if(self.whether_first_running()):
+                #首次运行
+                ###print("首次运行")
                 cur_date=str(datetime.datetime.now()).split(" ")[0]
                 ###cur_date=str(datetime.datetime.now()).replace(" ","").replace(":","")
                 self.date_info={"ori":cur_date}
                 filename=self.init_config["filename_pre"]+"_"+cur_date+".log"
-                ###print(filename)
                 fullpath = os.path.join(self.init_config["path"], filename)
                 self.log = self.init_log(fullpath,filename)
-        self.log.info(content)
+            else:
+                #非首次运行
+                ###print("非首次运行")
+                if(self.whether_init_log(self.date_info["ori"])):
+                    #跨天，重新初始化
+                    cur_date=str(datetime.datetime.now()).split(" ")[0]
+                    ###cur_date=str(datetime.datetime.now()).replace(" ","").replace(":","")
+                    self.date_info={"ori":cur_date}
+                    filename=self.init_config["filename_pre"]+"_"+cur_date+".log"
+                    ###print(filename)
+                    fullpath = os.path.join(self.init_config["path"], filename)
+                    self.log = self.init_log(fullpath,filename)
+            self.log.info(content)
+        except Exception as err:
+            print(err)
 
 def instance():
     return WeLog()
